#include "SDL/SDL.h"
#include "SDL/SDL_image.h"
#include "SDL/SDL_ttf.h"

#include <string>
#include <sstream>

#include "shared.h"
#include "Text_editor.h"

Text_editor::Text_editor(int x, int y, int w, int h, std::string start_message, std::string start_value)
{
    box.x=x;
    box.y=y;
    box.w=w;
    box.h=h;

    active = false;
    pushed = false;

    for(int i=0 ; i<10 ; i++)
	{
	text[i] = "";
	text_picture[i] = NULL;
	}
	text[0] = start_message;
    text[1] = start_value;


	line = 1;
}

Text_editor::~Text_editor()
{
	//Free text surface
        for(int i=0; i<= line ; i++)
        {
	SDL_FreeSurface( text_picture[i] );
	}
}

bool Text_editor::input_keyboard(unsigned char &user)
{
bool updated = false;

	if( event.type == SDL_KEYDOWN )// && (last_input != (char)event.key.keysym.sym || pushed == false) )
    {
        if( ( event.key.keysym.unicode >= (Uint16)' ' ) && ( event.key.keysym.unicode <= 0x7F ) )
        {
        	//Append the character
        	user = (unsigned char)event.key.keysym.unicode;
        	text[line] += (char)event.key.keysym.unicode;
        }

        if( event.key.keysym.sym == SDLK_BACKSPACE )
        {
			clear();
        }

		if( event.key.keysym.sym == SDLK_RETURN )
        {
			//Not tested
			std::string compare;
			compare = "COM";
			if (text[line].compare(0,3,compare,0,3) == 0)
			{
				//com_port = text[line];
			}

			if(line < 9)
			line++;
        }
    updated = true;
	}
return updated;
}

void Text_editor::input(unsigned char *buffer, int length)
{
	for(int i=0; i<length; i++)
	{
		if(buffer[i] >= (Uint8)' ' && buffer[i] <= 0x7F)
		{
            text[line] += buffer[i];
		}
	}
}

void Text_editor::clear()
{
	for(int i=1 ; i<10 ; i++)
	{
        text[i] = "";
        SDL_FreeSurface(text_picture[i]);
        text_picture[i] = NULL;
	}
	line = 1;
}


void Text_editor::apply_text()
{
        for(int i=0; i<= line ; i++)
        {
		SDL_FreeSurface( text_picture[i] );
		text_picture[i] = TTF_RenderText_Solid( font_14, text[i].c_str(), Color_black );
		if(text_picture[i] != NULL)
		{
		apply_surface( box.x, box.y + text_picture[0]->h * i, text_picture[i], screen);
		}
	}

	if(text_picture[line] != NULL)
	{
		if(text_picture[line]->w > 400)
		{
		if(line < 9)
		line++;
		if(line == 9)
		clear();
		}
	}
}

bool Text_editor::is_active()
{
    return active;
}

bool Text_editor::check()
{
int posx, posy;

	SDL_GetMouseState(&posx , &posy );

	if(SDL_GetMouseState(NULL , NULL ) & SDL_BUTTON(1) && event.type == SDL_MOUSEBUTTONDOWN)
	{
        //set false if another mouseclick is detected
        active = false;

		if( posx > box.x
		&&  posx < box.x + box.w
		&&  posy > box.y
		&&  posy < box.y + box.h )
        {
        pushed=true;
		}
	}

	if( event.type == SDL_MOUSEBUTTONUP && pushed==true)
	{
		pushed=false;
		SDL_GetMouseState(&posx, &posy);

        if( posx > box.x
		&&  posx < box.x + box.w
		&&  posy > box.y
		&&  posy < box.y + box.h )
        {
        active = true;
		return(true);
        }
	}
return (false);
}

std::string Text_editor::get_line(int line_number)
{
    return text[line_number];
}

void Text_editor::new_line()
{
    line++;
}
